* Pay, peek, punish? Repayment, information acquisition and punishment in a microcredit lab-in-the-field experiment

* Data from lab-in-the-field experiment with microcredit clients in rural India
* April 2011 in Supaul, Bihar, India
* 

version 13
clear all
set mem 1500m, perm
set more off, perm
capture log close 	


* Load data
use  Czura2015_PayPeekPunish_data.dta, clear

***************************
* Data preparation
***************************

* generate dummy of extenstion
tab extension, gen(ex)
rename ex1 ex_monitoring
rename ex2 ex_punishment
rename ex3 ex_combination

* calculate repayment types
gen type=1     if  s2b_repay_cond_yes==1 &  s2c_repay_cond_no==1
replace type=2 if  s2b_repay_cond_yes==0 &  s2c_repay_cond_no==0
replace type=3 if  s2b_repay_cond_yes==1 &  s2c_repay_cond_no==0
replace type=4 if  s2b_repay_cond_yes==0 &  s2c_repay_cond_no==1
label define type 1"always_repay_conditiona" 2"never_repay_conditiona" 3"reciprocal_repay" 4"converse_repay"
label value type type

* generate variable for unconditional repayment decision in extension game and repayment beliefs of partner
gen repay_extension = m4_repay
replace repay_extension=  p2_repay if repay_extension==.
replace repay_extension=  c4_repay if repay_extension==.
label var repay_extension "Unconditional repayment decision in extension game"
label define yesno 1 "yes" 0 "no"
label value repay_extension yesno

gen repay_belief_extension= m5_repay_belief
replace repay_belief_extension= p3_repay_belief if repay_belief_extension==.
replace repay_belief_extension= c5_repay_belief if repay_belief_extension==.
label var repay_belief_extension "Belief about partner's repayment decision in extension"
label value repay_belief_extension yesno

* generate variable for monitoring and punishment decision and beliefs
gen mon_extension= m2_monitoring
replace mon_extension=c2_monitoring if mon_extension==.
label var mon_extension "Monitoring decision in extension game" 
label value mon_extension  yesno

gen mon_belief_extension= m3_monitoring_belief
replace mon_belief_extension= c3_monitoring_belief if mon_belief_extension==.
label var mon_belief_extension "Belief about partner's monitoring decision in extension game" 
label value mon_belief_extension yesno

gen pun_extension=p6_punishment
replace  pun_extension= c9a_punishment_unconditional if  pun_extension==.
label var pun_extension "Punishment decision in extenstion game - unconditional punishment" 
label value pun_extension yesno

gen pun_belief_extension=p7a_punish_belief_unconditional
replace  pun_belief_extension= c10a_punish_belief_unconditional if  pun_belief_extension==.
label var pun_belief_extension "Belief about partner's punishment decision in extenstion game - unconditional punishment" 
label value pun_belief_extension yesno

* define as unreasonable:
* participants who 
* a) choose to unconditionally repay and never repay in conditional repayment decisions (8 partipants)
* b) choose to unconditionally default and always repay in conditinal repayment decisions (2 participants)			
gen unreasonable=1 if  (type==1 &  s2a_repay_uncond==0) |  (type==2 &  s2a_repay_uncond==1)		
replace unreasonable=0 if unreasonable ==.		

********************************************************************
*** Analyses and Tables
********************************************************************
* TABLE 1: CLIENT CHARACTERISTICS 
**********************************************
* client characteristics
estpost tabstat  i1_age i4_hh_mem i5_educ literate income_TRS membership_month if extension!=0, by(extension) stats (mean sd count)columns(statistic) listwise
estimates store tab1_stats_characteristics
foreach var of varlist  i1_age i4_hh_mem i5_educ literate income_TRS membership_month {
reg `var'  ex_pu ex_mo  if extension!=0   ,vce(cluster JLG)
test ex_pu+_cons=ex_mo+_cons=_cons
}
*
* Clients' occupation
tab i7_occupation, gen(occup_dum)
estpost tabstat  occup_dum* if extension!=0, by(extension) stats (mean sd count) columns(statistic) listwise
foreach num of numlist 1/6{
reg   occup_dum`num' ex_pu ex_mo  
test ex_pu+_cons=ex_mo+_cons=_cons
}
*
* create dummies for housewifes and business owners
gen client_housework=1 if i7_occupation==10
replace client_housework=0 if client_housework==.
gen client_business=1 if  i7_occupation==3
replace client_business=0 if client_business==.
gen no_client_business=0 if client_business==1
replace no_client_business=1 if client_business==0


* Relation to HH head
tab i3_relation, gen(relation_dum)
estpost tabstat  relation_dum* if extension!=0, by(extension) stats (mean sd count) columns(statistic) listwise
foreach num of numlist 1/5{
reg   relation_dum`num' ex_pu ex_mo 
test ex_pu+_cons=ex_mo+_cons=_cons
}
*

* TABLE 3: REPAYMENT; PEEKING; PUNISHMENT DECISIONS
**********************************************
* standard game
estpost tabstat  s2a_repay_uncond s2b_repay_cond_yes s2c_repay_cond_no s3_repay_belief, stats(mean sd count) by(ext) columns(statistic) 
foreach var of varlist s2a_repay_uncond s2b_repay_cond_yes s2c_repay_cond_no s3_repay_belief {
reg `var' ex_monitoring ex_punishment, vce(cluster JLG)
test ex_monitoring+_cons=ex_punishment+_cons=_cons
}
*
* treatment game
estpost tabstat  repay_extension repay_belief_extension mon_extension mon_belief_extension pun_extension pun_belief_extension, stats(mean sd count) by(ext) columns(statistic) 
foreach var of varlist repay_extension repay_belief_extension mon_extension mon_belief_extension pun_extension pun_belief_extension {
reg `var' ex_monitoring ex_punishment, vce(cluster JLG)
test ex_monitoring+_cons=ex_punishment+_cons=_cons
}
*
* montoring extension
estpost  tabstat c9b_punish_condi_unwilling c9c_punish_condi_willing c10b_punish_belief_condi_repay c10c_punish_belief_condi_norepay, stats(mean sd count) by(ext) columns(statistic) 

* Wilcoxon test of differences in punishment decisions: Wilcoxon matched-pairs signed-ranks test
signrank  c9a_punishment_uncond=c9b_punish_condi_unwilling
signrank  c9a_punishment_uncond=c9c_punish_condi_willing
signrank  c9b_punish_condi_unwilling= c9c_punish_condi_willing

* Repayment types
graph bar (count) slno, over(type) asyvar percentage ///
	bargap(20) ///
	ytitle("Repayment type - % of participants") ///
    showyvars ///
	yvaroptions(relabel (1 `"`""Always" "repay"'"' ///
						 2 `"`""Never" "repay"'"' ///
						 3 `"`""Repay" "reciprocal"'"'  ///
						 4 `"`""Repay "conversely"'"') ) ///
	legend(off) 	
		
* TABLE 5: Determinants of repayment in standard game
***************************************************************
foreach var of varlist s2a_repay_uncond s2b_repay_cond_yes s2c_repay_cond_no{
reg  `var' i1_age  i.i3_relation i4_hh_mem i5_educ literate membership_month income_TRS  ,vce(cluster JLG)
reg  `var' ex_punishment  ex_monitoring   ,vce(cluster JLG)
reg  `var' ex_punishment  ex_monitoring  i1_age i.i3_relation i4_hh_mem i5_educ literate membership_month income_TRS,vce(cluster JLG)
}
*

*******************************************************************************		
*** LONG DATA SET - COMPARE STANDARD AND TREATMENT GAME DECISIONS
*******************************************************************************
* compare per participant decision in standard and treatment game

* prepare data
gen dec_repay_1= s2a_repay_uncond
gen dec_repay_2= repay_extension
	
reshape  long dec_repay_, i(slno) j(game)

label define game 1"standard" 2"treatment"
label value game game

gen treat=1 if game==2 
replace treat=0 if game==1
	
tab slno, gen(id)	

* regress before and after (standard vs. treatment) for all treatment games
gen treat_expun= treat*ex_pun
gen treat_exmon= treat*ex_mon

*** TABLE 4: DIFFERENCES IN STANDARD AND TREATMENT GAMES ACROSS TREATMENTS
****************************************************************************
reg repay_ext ex_mon ex_pun  s2a_repay_uncond if treat==1, vce(cluster JLG)
test ex_mon=ex_pun 	

reg dec_repay treat ex_mon ex_pun treat_exmon treat_expun, vce(cluster slno)
test ex_mon=ex_pun 	
test treat_exmon=treat_expun 	
test treat=treat_expun 	
test treat=treat_exmon 	

reg dec_repay treat treat_exmon treat_expun i.slno, vce(cluster slno)
test treat_exmon=treat_expun 	
test treat=treat_expun 	
test treat=treat_exmon 	
		
*** TABLE 6: ROBUSTNESS CHECK OF TABLE 3 WITH DIFFERENT SAMPLE RESTRICTIONS
****************************************************************************
* robustness checks
* only unreasonable answers
* no housewifes	
* only business women	
foreach var of varlist unreasonable client_housework no_client_business{
reg repay_ext ex_mon ex_pun  s2a_repay_uncond if treat==1 & `var'==0, vce(cluster JLG)
reg dec_repay treat ex_mon ex_pun treat_exmon treat_expun if  `var'==0, vce(cluster slno)
reg dec_repay treat treat_exmon treat_expun i.slno if  `var'==0, vce(cluster slno)
}
*

exit
